==> PPDF_1_0.zip: PubMedPDF/register.php <==
<?php
	include "header.php";
	include "include/check_perm.php";
	include "include/conn.php";	
		
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";

	## ϿꥹȤɽ
	if(@$_GET["showlist"]){

		$how = @$_GET["how"];
		if(@$_GET["usr_only"]){
			$sql = "SELECT PMID FROM ".$T_ID." WHERE R_usr='".$user."' ORDER BY PMID";
		}else{
			$sql = "SELECT PMID FROM ".$T_ID." ORDER BY PMID";		
		}
		$up_pass = $xoopsModuleConfig['updir'];
		if(substr($up_pass,-1) != "/") $up_pass.="/";
		
		if($how == "all"){
			echo "<b>ǡPMID</b><br>";
			$data = "";
			$res = mysql_query($sql, $conn);
			while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
				if($row["PMID"] > 0) $data .= $row["PMID"].",";
			}
			$data = substr($data, 0, -1);
			$fp = fopen("datalist.txt", "w");
			fputs($fp, $data);
			fclose($fp);
			header("Location:".XOOPS_URL."/modules/PubMedPDF/export.php");

		}elseif($how == "have"){
			echo "<b>PDFǡPMID</b><br>";
			$data = "";
			$res = mysql_query($sql, $conn);
			while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
				if(file_exists($up_pass.$row["PMID"].".pdf")){
					$data .= $row["PMID"].",";
				}
			}
			$data = substr($data, 0, -1);
			$fp = fopen("datalist.txt", "w");
			fputs($fp, $data);
			fclose($fp);
			header("Location:".XOOPS_URL."/modules/PubMedPDF/export.php");

		}elseif($how == "havenot"){
			echo "<b>PDFʤǡPMID</b><br>";
			$data = "";
			$res = mysql_query($sql, $conn);
			while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
				if(!file_exists($up_pass.$row["PMID"].".pdf")){
					if($row["PMID"] > 0) $data .= $row["PMID"].",";
				}
			}
			$data = substr($data, 0, -1);
			$fp = fopen("datalist.txt", "w");
			fputs($fp, $data);
			fclose($fp);
			header("Location:".XOOPS_URL."/modules/PubMedPDF/export.php");

		}

	## ꥹȥåץɤǤΰϿ
	}elseif(@$_POST["auto_run2"]){

		if(is_uploaded_file($_FILES['userfile']['tmp_name'])){

			$file_name = $_FILES['userfile']['name'];
			copy($_FILES['userfile']['tmp_name'], "tmp.txt");
			if(file_exists("tmp.txt")){
				$data = "";
				$fp = fopen("tmp.txt", "r");
				while(!feof($fp)){
					$data .= fgets($fp);
				}
				fclose($fp);
				unlink("tmp.txt");
				
				$pmid = explode(",", $data);

				## Proxy
				if($xoopsModuleConfig['proxy']){
					include (XOOPS_ROOT_PATH."/class/snoopy.php");
					$proxy = new Snoopy;
					$proxy->read_timeout = 0;
					$proxy->proxy_host = $xoopsModuleConfig['proxy_url'];
					$proxy->proxy_port = $xoopsModuleConfig['proxy_port'];
				}else{
					$proxy = 0;
				}
				
				include "include/pubmed.php";
				include "include/db.php";

				$count = 0;
				for($i=0; $i<count($pmid); $i++){
					echo "[".$pmid[$i]."] ";	
					$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$pmid[$i]."'";
					$res = mysql_query($sql, $conn);
					if(mysql_num_rows($res) != 0){
						echo "already registered.<br>";
					}else{
						if($count > 70){
							for($j=0;$j<10000;$j++);
							$count = 0;
						}
						
						if(file_exists("pubmed_xml/$pmid[$i].xml")){
							$pm_data = PubMedByFile( $pmid[$i], 'pubmed_xml/', 0 );
   	  						echo $pm_data[t]."<br>";
							DB($pm_data, $user);
						} else if(file_exists("search_xml/$pmid[$i].xml")){
							$pm_data = PubMedByFile( $pmid[$i], 'search_xml/', 0 );
   	  						echo $pm_data[t]."<br>";
							DB($pm_data, $user);
							rename( "search_xml/$pmid[$i].xml", "pubmed_xml/$pmid[$i].xml" );
						} else {
							if(!$pm_data = PubMed($pmid[$i],$proxy,'pubmed_xml/')){
								echo "id missing...<br>";
	 		      			}else{
	     		  				echo $pm_data[t]."<br>";
								DB($pm_data, $user);
    			   			}
						}
					}
    	   			$count ++;
    			}
    		}
		}else{
			echo "upload failed.";
		}

	## Ƽե
	}else{

		include "style.php";

		echo "<div class=\"pt\">"._MD_PDF_A."</div>";
		echo "<div class=\"pc\">";
		echo _MD_PDF_A_DESC;
		echo "<br><br><form enctype=\"multipart/form-data\" action=\"upload.php\" method=\"POST\">";
		echo "<input type=\"file\" name=\"userfile\">";
		echo "<input type=\"submit\" name=\"upload\" value=\"submit\">";
		echo "</form></div>";
		
		echo "<div class=\"pt\">"._MD_PDF_B."</div>";
		echo "<div class=\"pc\">";
		echo _MD_PDF_B_DESC;
		echo "<br><br><form action=\"upload.php\" method=\"POST\">";
		echo "<input type=\"id\" name=\"pmid\">";
		echo "<input type=\"submit\" name=\"regist_id\" value=\"submit\">";
		echo "</form></div>";
		
		if(Check_permission($user)){
			echo "<div class=\"pt\">"._MD_PDF_C."</div>";
			echo "<div class=\"pc\">";
			echo _MD_PDF_C_DESC;
			echo "<br><br><form action=\"auto_run.php\">";
			echo "<input type=\"submit\" value=\"submit\">";
			echo "</form></div>";
		}
		
		echo "<div class=\"pt\">"._MD_PDF_D."</div>";
		echo "<div class=\"pc\">";
		echo _MD_PDF_D_DESC;
		echo "<br><br><form enctype=\"multipart/form-data\" action=\"".$_SERVER[PHP_SELF]."\" method=\"POST\">";
		echo "<input type=\"file\" name=\"userfile\">";
		echo "<input type=\"submit\" name=\"auto_run2\" value=\"submit\">";
		echo "</form></div>";
		
		echo "<div class=\"pt\">"._MD_PDF_E."</div>";
		echo "<div class=\"pc\">";
		echo _MD_PDF_E_DESC;
		echo "<br><br><form action=\"".$_SERVER[PHP_SELF]."\" method=\"GET\">";
		echo "<input type=\"radio\" name=\"how\" value=\"havenot\" checked>"._MD_L1;
		echo "<input type=\"radio\" name=\"how\" value=\"have\">"._MD_L2;
		echo "<input type=\"radio\" name=\"how\" value=\"all\">"._MD_L3."<br>";
		echo "<input type=\"checkbox\" name=\"usr_only\" value=\"y\">"._MD_L4."<br><br>";
		echo "<input type=\"submit\" name=\"showlist\" value=\"download\">";
		echo "</form></div>";
		
		//XML archive download
		echo "<div class=\"pt\">"._MD_XML_DOWNLOAD."</div>";
		echo "<div class=\"pc\">"._MD_XML_DOWNLOAD_DESC."<br>";
		echo "<a href=\"downloader.php?dir=w\">[Download]</a></div>";

		echo "<div class=\"pt\">"._MD_PDF_F."</div>";
		echo "<div class=\"pc\">";
		echo _MD_PDF_F_DESC;
		echo "<br><br><form action=\"delete.php\" method=\"GET\">";
		echo "<input type=\"text\" name=\"id\">";
		echo "<input type=\"submit\" name=\"upload\" value=\"submit\">";
		echo "</form></div>";

	}

	include (XOOPS_ROOT_PATH."/footer.php");
?>

==> PPDF_1_3.zip: PubMedPDF/register.php <==
<?php
	include "header.php";
	include "include/check_perm.php";
	include "include/conn.php";	
		
	($xoopsUser) ? $user = $xoopsUser->uname() : $user="guest";

	## ϿꥹȤɽ
	if(@$_GET["showlist"]){

		$how = @$_GET["how"];
		if(@$_GET["usr_only"]){
			$sql = "SELECT PMID FROM ".$T_ID." WHERE R_usr='".$user."' ORDER BY PMID";
		}else{
			$sql = "SELECT PMID FROM ".$T_ID." ORDER BY PMID";		
		}
		$up_pass = $xoopsModuleConfig['updir'];
		if(substr($up_pass,-1) != "/") $up_pass.="/";
		
		if($how == "all"){
			#all data
			$data = "";
			$res = mysql_query($sql, $conn);
			while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
				if($row["PMID"] > 0) $data .= $row["PMID"].",";
			}
			$data = substr($data, 0, -1);
			$fp = fopen("datalist.txt", "w");
			fputs($fp, $data);
			fclose($fp);
			header("Location:".XOOPS_URL."/modules/PubMedPDF/export.php");

		}elseif($how == "have"){
			#PMID with PDF
			$data = "";
			$res = mysql_query($sql, $conn);
			while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
				if(file_exists($up_pass.$row["PMID"].".pdf")){
					$data .= $row["PMID"].",";
				}
			}
			$data = substr($data, 0, -1);
			$fp = fopen("datalist.txt", "w");
			fputs($fp, $data);
			fclose($fp);
			header("Location:".XOOPS_URL."/modules/PubMedPDF/export.php");

		}elseif($how == "havenot"){
			#PMID without PDF
			$data = "";
			$res = mysql_query($sql, $conn);
			while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
				if(!file_exists($up_pass.$row["PMID"].".pdf")){
					if($row["PMID"] > 0) $data .= $row["PMID"].",";
				}
			}
			$data = substr($data, 0, -1);
			$fp = fopen("datalist.txt", "w");
			fputs($fp, $data);
			fclose($fp);
			header("Location:".XOOPS_URL."/modules/PubMedPDF/export.php");

		}

	## ꥹȥåץɤǤΰϿ
	}elseif(@$_POST["auto_run2"]){

		if(is_uploaded_file($_FILES['userfile']['tmp_name'])){

			$file_name = $_FILES['userfile']['name'];
			copy($_FILES['userfile']['tmp_name'], "tmp.txt");
			if(file_exists("tmp.txt")){
				$data = "";
				$fp = fopen("tmp.txt", "r");
				while(!feof($fp)){
					$data .= fgets($fp);
				}
				fclose($fp);
				unlink("tmp.txt");
				
				$pmid = explode(",", $data);

				## Proxy
				include (XOOPS_ROOT_PATH."/class/snoopy.php");
				if($xoopsModuleConfig['proxy']){
					$proxy = new Snoopy;
					$proxy->read_timeout = 0;
					$proxy->proxy_host = $xoopsModuleConfig['proxy_url'];
					$proxy->proxy_port = $xoopsModuleConfig['proxy_port'];
				}else{
					$proxy = 0;
					$snoopy = new Snoopy;
				}
				
				include "include/pubmed.php";
				include "include/db.php";

				$count = 0;
				for($i=0; $i<count($pmid); $i++){
					#echo "[".$pmid[$i]."] ";	
					$sql = "SELECT * FROM ".$T_ID." WHERE PMID='".$pmid[$i]."'";
					$res = mysql_query($sql, $conn);
					if(mysql_num_rows($res) != 0){
					#	echo "already registered.<br>";
					}else{
						if($count > 70){
							for($j=0;$j<10000;$j++);
							$count = 0;
						}
						
						if(file_exists("pubmed_xml/$pmid[$i].xml")){
							$pm_data = PubMedByFile( $pmid[$i], 'pubmed_xml/', 0 );
   	  						echo $pm_data[t]."<br>";
							DB($pm_data, $user);
						} else if(file_exists("search_xml/$pmid[$i].xml")){
							$pm_data = PubMedByFile( $pmid[$i], 'search_xml/', 0 );
   	  						echo $pm_data[t]."<br>";
							DB($pm_data, $user);
							rename( "search_xml/$pmid[$i].xml", "pubmed_xml/$pmid[$i].xml" );
						} else {
							if(!$pm_data = PubMed($pmid[$i],$proxy,$snoopy,'pubmed_xml/')){
							#	echo "id missing...<br>";
	 		      			}else{
	     		  				echo $pm_data[t]."<br>";
								DB($pm_data, $user);
    			   			}
						}
					}
    	   			$count ++;
    			}
    		}
		}else{
			echo "upload failed.";
		}

	## Ƽե
	}else{

		include "style.php";

		echo "<div class=\"pt\">"._MD_PDF_A."</div>";
		echo "<div class=\"pc\">";
		echo _MD_PDF_A_DESC;
		echo "<br><br><form enctype=\"multipart/form-data\" action=\"upload.php\" method=\"POST\">";
		echo "<input type=\"file\" name=\"userfile\">";
		echo "<input type=\"submit\" name=\"upload\" value=\"submit\">";
		echo "</form></div>";
		
		echo "<div class=\"pt\">"._MD_PDF_B."</div>";
		echo "<div class=\"pc\">";
		echo _MD_PDF_B_DESC;
		echo "<br><br><form action=\"upload.php\" method=\"POST\">";
		echo "<input type=\"id\" name=\"pmid\">";
		echo "<input type=\"submit\" name=\"regist_id\" value=\"submit\">";
		echo "</form></div>";
		
		if(Check_permission($user)){
			echo "<div class=\"pt\">"._MD_PDF_C."</div>";
			echo "<div class=\"pc\">";
			echo _MD_PDF_C_DESC;
			echo "<br><br><form action=\"auto_run.php\">";
			echo "<input type=\"submit\" value=\"submit\">";
			echo "</form></div>";
		}
		
		echo "<div class=\"pt\">"._MD_PDF_D."</div>";
		echo "<div class=\"pc\">";
		echo _MD_PDF_D_DESC;
		echo "<br><br><form enctype=\"multipart/form-data\" action=\"".$_SERVER[PHP_SELF]."\" method=\"POST\">";
		echo "<input type=\"file\" name=\"userfile\">";
		echo "<input type=\"submit\" name=\"auto_run2\" value=\"submit\">";
		echo "</form></div>";
		
		echo "<div class=\"pt\">"._MD_PDF_E."</div>";
		echo "<div class=\"pc\">";
		echo _MD_PDF_E_DESC;
		echo "<br><br><form action=\"".$_SERVER[PHP_SELF]."\" method=\"GET\">";
		echo "<input type=\"radio\" name=\"how\" value=\"havenot\" checked>"._MD_L1;
		echo "<input type=\"radio\" name=\"how\" value=\"have\">"._MD_L2;
		echo "<input type=\"radio\" name=\"how\" value=\"all\">"._MD_L3."<br>";
		echo "<input type=\"checkbox\" name=\"usr_only\" value=\"y\">"._MD_L4."<br><br>";
		echo "<input type=\"submit\" name=\"showlist\" value=\"download\">";
		echo "</form></div>";
		
		//XML archive download
		echo "<div class=\"pt\">"._MD_XML_DOWNLOAD."</div>";
		echo "<div class=\"pc\">"._MD_XML_DOWNLOAD_DESC."<br>";
		echo "<a href=\"downloader.php?dir=w\">[Download]</a></div>";

		echo "<div class=\"pt\">"._MD_PDF_F."</div>";
		echo "<div class=\"pc\">";
		echo _MD_PDF_F_DESC;
		echo "<br><br><form action=\"delete.php\" method=\"GET\">";
		echo "<input type=\"text\" name=\"id\">";
		echo "<input type=\"submit\" name=\"upload\" value=\"submit\">";
		echo "</form></div>";

	}

	include (XOOPS_ROOT_PATH."/footer.php");
?>
